# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""VistaSoft contains Matlab code to perform a variety of analysis on MRI data."""
from .vista import Vnifti2Image, VtoMat
