# -*- coding: utf-8 -*-
# -*- coding: utf8 -*-
"""Autogenerated file - DO NOT EDIT
If you spot a bug, please report it on the mailing list and/or change the generator."""

from nipype.interfaces.base import (
    CommandLine,
    CommandLineInputSpec,
    SEMLikeCommandLine,
    TraitedSpec,
    File,
    Directory,
    traits,
    isdefined,
    InputMultiPath,
    OutputMultiPath,
)
import os


class LandmarksCompareInputSpec(CommandLineInputSpec):
    inputLandmarkFile1 = File(
        desc="First input landmark file (.fcsv or .wts)",
        exists=True,
        argstr="--inputLandmarkFile1 %s",
    )
    inputLandmarkFile2 = File(
        desc="Second input landmark file (.fcsv or .wts)",
        exists=True,
        argstr="--inputLandmarkFile2 %s",
    )
    tolerance = traits.Float(
        desc="The maximum error (in mm) allowed in each direction of a landmark",
        argstr="--tolerance %f",
    )


class LandmarksCompareOutputSpec(TraitedSpec):
    pass


class LandmarksCompare(SEMLikeCommandLine):
    """title: Compare Fiducials

    category: Testing

    description: Compares two .fcsv or .wts text files and verifies that they are identicle.  Used for testing landmarks files.

    contributor: Ali Ghayoor
    """

    input_spec = LandmarksCompareInputSpec
    output_spec = LandmarksCompareOutputSpec
    _cmd = " LandmarksCompare "
    _outputs_filenames = {}
    _redirect_x = False
