# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import IdentityInterface


def test_IdentityInterface_inputs():
    input_map = dict()
    inputs = IdentityInterface.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_IdentityInterface_outputs():
    output_map = dict()
    outputs = IdentityInterface.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
