# -*- coding: utf-8 -*-
# -*- coding: utf8 -*-
"""Autogenerated file - DO NOT EDIT
If you spot a bug, please report it on the mailing list and/or change the generator."""

import os

from ..base import (
    CommandLine,
    CommandLineInputSpec,
    SEMLikeCommandLine,
    TraitedSpec,
    File,
    Directory,
    traits,
    isdefined,
    InputMultiPath,
    OutputMultiPath,
)


class GenerateCsfClippedFromClassifiedImageInputSpec(CommandLineInputSpec):
    inputCassifiedVolume = File(
        desc="Required: input tissue label image",
        exists=True,
        argstr="--inputCassifiedVolume %s",
    )
    outputVolume = traits.Either(
        traits.Bool,
        File(),
        hash_files=False,
        desc="Required: output image",
        argstr="--outputVolume %s",
    )


class GenerateCsfClippedFromClassifiedImageOutputSpec(TraitedSpec):
    outputVolume = File(desc="Required: output image", exists=True)


class GenerateCsfClippedFromClassifiedImage(SEMLikeCommandLine):
    """title: GenerateCsfClippedFromClassifiedImage

    category: FeatureCreator

    description: Get the distance from a voxel to the nearest voxel of a given tissue type.

    version: 0.1.0.$Revision: 1 $(alpha)

    documentation-url: http:://www.na-mic.org/

    license: https://www.nitrc.org/svn/brains/BuildScripts/trunk/License.txt

    contributor: This tool was written by Hans J. Johnson.
    """

    input_spec = GenerateCsfClippedFromClassifiedImageInputSpec
    output_spec = GenerateCsfClippedFromClassifiedImageOutputSpec
    _cmd = " GenerateCsfClippedFromClassifiedImage "
    _outputs_filenames = {"outputVolume": "outputVolume.nii"}
    _redirect_x = False
